<h1 align="center">Manrododex</br>
<sup><sup>マンロードデクス</sup></sup></h1>

### A manga downloader for mangadex using their [API](https://api.mangadex.org/docs/)
![](https://img.shields.io/github/license/Sydiepus/Manrododex)
![](https://img.shields.io/github/issues/Sydiepus/Manrododex)
![](https://img.shields.io/pypi/pyversions/manrododex)
![GitHub Workflow Status](https://github.com/Sydiepus/Manrododex/actions/workflows/CI.yml/badge.svg)
![PyPI](https://img.shields.io/pypi/v/manrododex)
## Features

- Threads support for faster downloads.
- Uses queue for safe threading and better memory usage.
- Creates a series.json file like mylar. (
  see [here](https://komga.org/guides/scan-analysis-refresh.html#import-metadata-generated-by-mylar)
  and [here](https://github.com/mylar3/mylar3/wiki/series.json-examples))
- Can be used to automate the download of manga in combination with crontabs/Scheduled Tasks.
- Manrododex makes it possible to download multiple manga with little to user interaction.
- A possibly wrong Japanese translation of the name.
- Bugs

## Inspiration

I might have stolen some ideas from these awesome projects.

- [manga-py](https://github.com/manga-py/manga-py)
- [mangadex-dl](https://github.com/frozenpandaman/mangadex-dl)
- [MangaDex.py](https://github.com/Proxymiity/MangaDex.py)
- [Qtile](https://github.com/qtile/qtile)

## Maintainer

[@Sydiepus](https://github.com/Sydiepus) GPG: ```BD1D 09DF 8A49 E7A6 C705 3B8A 7D6C DB7E 575A C12A```

## Note:

- I'll be taking a break for some time and might not be able to properly test or fix the program.
- Not tested on Windows yet.
- wiki coming soon.